;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME: PITIMER12_1.asm
;;   Version: 1.1, Updated on 2011/12/1 at 17:19:6
;;  Generated by PSoC Designer 5.2.2401
;;
;;  DESCRIPTION: PITIMER User Module software implementation file.
;;
;;  NOTE: User Module APIs conform to the fastcall16 convention for marshalling
;;        arguments and observe the associated "Registers are volatile" policy.
;;        This means it is the caller's responsibility to preserve any values
;;        in the X and A registers that are still needed after the API functions
;;        returns. For Large Memory Model devices it is also the caller's 
;;        responsibility to perserve any value in the CUR_PP, IDX_PP, MVR_PP and 
;;        MVW_PP registers. Even though some of these registers may not be modified
;;        now, there is no guarantee that will remain the case in future releases.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress Semiconductor 2011. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "m8c.inc"
include "memory.inc"
include "PITIMER12_1.inc"

;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------
export   PITIMER12_1_EnableInt
export  _PITIMER12_1_EnableInt
export   PITIMER12_1_DisableInt
export  _PITIMER12_1_DisableInt
export   PITIMER12_1_Start
export  _PITIMER12_1_Start
export   PITIMER12_1_Stop
export  _PITIMER12_1_Stop
export   PITIMER12_1_SetReload
export  _PITIMER12_1_SetReload
export   PITIMER12_1_GetReload
export  _PITIMER12_1_GetReload
export   PITIMER12_1_GetInterval
export  _PITIMER12_1_GetInterval

;-----------------------------------------------
;  Constant Definitions
;-----------------------------------------------

area UserModules (ROM, REL)

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: PITIMER12_1_EnableInt
;
;  DESCRIPTION:
;     Enables the PITIMER interrupt by setting the interrupt enable mask
;     bit associated with this User Module.
;
;     NOTE:  Remember to enable the global interrupt by calling the
;           M8C global macro: M8C_EnableGInt
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:  none
;
;  RETURNS:  none
;
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
;  THEORY of OPERATION or PROCEDURE:
;     Sets the specific user module interrupt enable mask bit.
;
;-----------------------------------------------------------------------------
 PITIMER12_1_EnableInt:
_PITIMER12_1_EnableInt:
    RAM_PROLOGUE RAM_USE_CLASS_1
    M8C_EnableIntMask    INT_MSK1, INT_MSK1_PIT ; Enable the interrupt
    RAM_EPILOGUE RAM_USE_CLASS_1
    RET
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: PITIMER12_1_DisableInt
;
;  DESCRIPTION:
;     Disables this PITIMER interrupt by clearing the interrupt enable mask bit
;     associated with this User Module.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:  none
;
;  RETURNS:  none
;
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
;  THEORY of OPERATION or PROCEDURE:
;     Clears the specific user module interrupt enable mask bit.
;
;-----------------------------------------------------------------------------
 PITIMER12_1_DisableInt:
_PITIMER12_1_DisableInt:
   RAM_PROLOGUE RAM_USE_CLASS_1
   M8C_DisableIntMask    INT_MSK1, INT_MSK1_PIT ; Disable the interrupt
   RAM_EPILOGUE RAM_USE_CLASS_1
   RET
.ENDSECTION
.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: PITIMER12_1_Stop
;
;  DESCRIPTION:
;     Disables PITIMER operation.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:  none
;
;  RETURNS:  none
;
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
;  THEORY of OPERATION or PROCEDURE:
;
;-----------------------------------------------------------------------------
 PITIMER12_1_Stop:
_PITIMER12_1_Stop:
   RAM_PROLOGUE RAM_USE_CLASS_1
   M8C_DisableIntMask    INT_MSK1, INT_MSK1_PIT ; Disable the interrupt
   RAM_EPILOGUE RAM_USE_CLASS_1
   RET
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME:  PITIMER12_1_Start
;                  PITIMER12_1_SetReload
;
;  DESCRIPTION:
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: A:X   12 bit Reload Value
;
;  RETURNS:  none
;
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
;  THEORY of OPERATION or PROCEDURE:
;
;-----------------------------------------------------------------------------
 PITIMER12_1_Start:
_PITIMER12_1_Start:
 PITIMER12_1_SetReload:
_PITIMER12_1_SetReload:
    RAM_PROLOGUE RAM_USE_CLASS_1
    MOV     REG[PIRL], A               ; Set the reload LSB first
    SWAP    A, X                       ; Get the MSB
    AND     A, 0x0F                    ; Make sure the upper 4 bits are clear (12 bit reload)
    MOV     REG[PIRH], A               ; Set the reload LSB first
    RAM_EPILOGUE RAM_USE_CLASS_1
    RET
.ENDSECTION
.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: PITIMER12_1_GetReload
;
;  DESCRIPTION:
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: None
;
;  RETURNS:   A:X   12 bit Reload Value
;
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
;  THEORY of OPERATION or PROCEDURE:
;
;-----------------------------------------------------------------------------
 PITIMER12_1_GetReload:
_PITIMER12_1_GetReload:
    RAM_PROLOGUE RAM_USE_CLASS_1
    MOV     A, REG[PIRL]               ; Get the reload LSB first
    SWAP    A, X                       ; Save the LSB
    MOV     A, REG[PIRH]               ; Get the reload MSB first
    AND     A, 0x0F                    ; Make sure the upper 4 bits are clear (12 bit reload)
    SWAP    A, X                       ; Put them into the right registers
    RAM_EPILOGUE RAM_USE_CLASS_1
    RET
.ENDSECTION
.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: PITIMER12_1_GetInterval
;
;  DESCRIPTION:
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: None
;
;  RETURNS:   A:X   12 bit Reload Value
;
;  SIDE EFFECTS: 
;    The A and X registers may be modified by this or future implementations
;    of this function.  The same is true for all RAM page pointer registers in
;    the Large Memory Model.  When necessary, it is the calling function's
;    responsibility to perserve their values across calls to fastcall16 
;    functions.
;
;  THEORY of OPERATION or PROCEDURE:
;
;-----------------------------------------------------------------------------
 PITIMER12_1_GetInterval:
_PITIMER12_1_GetInterval:
    RAM_PROLOGUE RAM_USE_CLASS_1
    MOV     A, REG[PITMRL]             ; Get the interval LSB first
    SWAP    A, X                       ; Save the LSB
    MOV     A, REG[PITMRH]             ; Get the interval MSB first
    AND     A, 0x0F                    ; Make sure the upper 4 bits are clear (12 bit reload)
    SWAP    A, X                       ; Put them into the right registers
    RAM_EPILOGUE RAM_USE_CLASS_1
    RET
.ENDSECTION
; End of File PITIMER12_1.asm
